@@ -85,8 +85,8 @@ private:
 
   QByteArray m_data;
 //  int m_total;
-  QHash<int, Data::EntryPtr> m_entries;
-  QHash<int, QUrl> m_matches;
+  QHash<uint, Data::EntryPtr> m_entries;
+  QHash<uint, QUrl> m_matches;
   QPointer<KIO::StoredTransferJob> m_job;
 
   bool m_started;
