@@ -87,12 +87,6 @@ void CrossRefFetcher::search() {
   m_started = true;
 
   readWallet();
-  if(m_email.isEmpty() && (m_user.isEmpty() || m_password.isEmpty())) {
-    myDebug() << i18n("%1 requires a username and password.", source());
-    message(i18n("%1 requires a username and password.", source()), MessageHandler::Error);
-    stop();
-    return;
-  }
 
 //  myDebug() << "value = " << value_;
 
@@ -102,6 +96,13 @@ void CrossRefFetcher::search() {
     return;
   }
 
+  if(m_email.isEmpty() && (m_user.isEmpty() || m_password.isEmpty())) {
+    myDebug() << i18n("%1 requires a username and password.", source());
+    message(i18n("%1 requires a username and password.", source()), MessageHandler::Error);
+    stop();
+    return;
+  }
+
   m_job = KIO::storedGet(u, KIO::NoReload, KIO::HideProgressInfo);
   KJobWidgets::setWindow(m_job, GUI::Proxy::widget());
   connect(m_job.data(), &KJob::result,
@@ -299,7 +300,7 @@ QString CrossRefFetcher::defaultName() {
 }
 
 QString CrossRefFetcher::defaultIcon() {
-  return favIcon("http://crossref.org");
+  return favIcon("https://www.crossref.org");
 }
 
 CrossRefFetcher::ConfigWidget::ConfigWidget(QWidget* parent_, const CrossRefFetcher* fetcher_)
