@@ -137,7 +137,7 @@ void DoubanFetcher::doSearch(const QString& term_) {
       break;
 
     default:
-      myWarning() << "key not recognized:" << request().key();
+      myWarning() << source() << "- key not recognized:" << request().key();
       return;
   }
 
