@@ -52,7 +52,7 @@ public:
   /**
    */
   virtual QString source() const Q_DECL_OVERRIDE;
-  virtual bool canSearch(FetchKey k) const Q_DECL_OVERRIDE { return k == Title || k == UPC; }
+  virtual bool canSearch(FetchKey k) const Q_DECL_OVERRIDE;
   virtual Type type() const Q_DECL_OVERRIDE { return DVDFr; }
   virtual bool canFetch(int type) const Q_DECL_OVERRIDE;
   virtual void readConfigHook(const KConfigGroup&) Q_DECL_OVERRIDE {}
