@@ -43,6 +43,7 @@
 #include <KCompressionDevice>
 #include <KTar>
 #include <KLocalizedString>
+#include <karchive_version.h>
 
 #include <QTemporaryDir>
 #include <QDir>
@@ -73,7 +74,7 @@ GCstarPluginFetcher::PluginList GCstarPluginFetcher::plugins(int collType_) {
         QString output = QString::fromLocal8Bit(proc.readAllStandardOutput());
         if(!output.isEmpty()) {
           // always going to be x.y[.z] ?
-          QRegularExpression versionRx(QLatin1String("(\\d+)\\.(\\d+)(?:\\.(\\d+))?"));
+          static const QRegularExpression versionRx(QLatin1String("(\\d+)\\.(\\d+)(?:\\.(\\d+))?"));
           QRegularExpressionMatch m = versionRx.match(output);
           if(m.hasMatch()) {
             int x = m.captured(1).toInt();
@@ -154,7 +155,7 @@ void GCstarPluginFetcher::readPluginsOld(int collType_, const QString& gcstar_)
   QDir dir(gcstar_, QStringLiteral("GC*.pm"));
   dir.cd(QStringLiteral("../../lib/gcstar/GCPlugins/"));
 
-  QRegularExpression rx(QLatin1String("get(Name|Author|Lang)\\s*\\{\\s*return\\s+['\"](.+?)['\"]"));
+  static const QRegularExpression rx(QLatin1String("get(Name|Author|Lang)\\s*\\{\\s*return\\s+['\"](.+?)['\"]"));
 
   PluginList plugins;
 
@@ -301,7 +302,11 @@ void GCstarPluginFetcher::slotProcessExited() {
   }
 
   QBuffer filterBuffer(&m_data);
-  KCompressionDevice::CompressionType compressionType = KFilterDev::compressionTypeForMimeType(QStringLiteral("application/x-gzip"));
+#if KARCHIVE_VERSION >= QT_VERSION_CHECK(5,85,0)
+  auto compressionType = KCompressionDevice::compressionTypeForMimeType(QStringLiteral("application/x-gzip"));
+#else
+  auto compressionType = KFilterDev::compressionTypeForMimeType(QStringLiteral("application/x-gzip"));
+#endif
   KCompressionDevice filter(&filterBuffer, false, compressionType);
   if(!filter.open(QIODevice::ReadOnly)) {
     myWarning() << "unable to open gzip filter";
