@@ -103,7 +103,7 @@ void KinoPoiskFetcher::search() {
       break;
 
     default:
-      myWarning() << "key not recognized: " << request().key();
+      myWarning() << source() << "- key not recognized:" << request().key();
       stop();
       return;
   }
