@@ -126,7 +126,7 @@ void MusicBrainzFetcher::doSearch() {
       break;
 
     default:
-      myWarning() << "key not recognized: " << request().key();
+      myWarning() << source() << "- key not recognized:" << request().key();
       stop();
       return;
   }
