@@ -126,7 +126,7 @@ void SRUFetcher::readConfigHook(const KConfigGroup& config_) {
 void SRUFetcher::search() {
   m_started = true;
   if(m_host.isEmpty() || m_path.isEmpty() || m_format.isEmpty()) {
-    myDebug() << "settings are not set!";
+    myDebug() << source() << "- host and path are not set!";
     stop();
     return;
   }
@@ -235,7 +235,7 @@ void SRUFetcher::search() {
       break;
 
     default:
-      myWarning() << "key not recognized: " << request().key();
+      myWarning() << source() << "- key not recognized:" << request().key();
       stop();
       break;
   }
@@ -498,7 +498,6 @@ QString SRUFetcher::defaultName() {
 }
 
 QString SRUFetcher::defaultIcon() {
-//  return QLatin1String("network-workgroup"); // just to be different than z3950
   return QStringLiteral(":/icons/sru");
 }
 
