@@ -631,7 +631,7 @@ void FetchDialog::slotShowEntry() {
 
   const QPixmap sourceIcon = Fetch::Manager::self()->fetcherIcon(r->fetcher());
   const QByteArray ba = Data::Image::byteArray(sourceIcon.toImage(), "PNG");
-  QString text = QStringLiteral("<qt><img src='data:image/png;base64,%1'/> %2<br/>%3</qt>")
+  QString text = QStringLiteral("<qt><img style='vertical-align: top' src='data:image/png;base64,%1'/> %2<br/>%3</qt>")
                  .arg(QLatin1String(ba.toBase64()), r->fetcher()->source(), r->fetcher()->attribution());
   entry->setField(QStringLiteral("fetchdialog_source"), text);
 
