@@ -28,6 +28,8 @@
 #include "fieldwidget.h"
 #include "../datavectors.h"
 
+class FieldWidgetTest;
+
 namespace Tellico {
   namespace GUI {
     class RatingWidget;
@@ -38,6 +40,8 @@ namespace Tellico {
 class RatingFieldWidget : public FieldWidget {
 Q_OBJECT
 
+friend class ::FieldWidgetTest;
+
 public:
   RatingFieldWidget(Data::FieldPtr field, QWidget* parent);
   virtual ~RatingFieldWidget() {}
