@@ -150,6 +150,7 @@ public Q_SLOTS:
    * @param type Type of collection to add
    */
   void slotFileNew(int type);
+  void slotFileNewByTemplate(const QString& collectionTemplate);
   /**
    * Opens a file and loads it into the document
    */
@@ -174,6 +175,7 @@ public Q_SLOTS:
    * Saves a document by a new filename
    */
   void slotFileSaveAs();
+  void slotFileSaveAsTemplate();
   /**
    * Prints the current document.
    */
@@ -484,6 +486,7 @@ private:
   QAction* m_checkOutEntry;
   KToggleAction* m_toggleEntryEditor;
   KDualAction* m_lockLayout;
+  KActionMenu* m_newCollectionMenu;
 
   KSelectAction* m_entryGrouping;
   GUI::LineEdit* m_quickFilter;
