@@ -116,7 +116,7 @@ QVariant BorrowerModel::data(const QModelIndex& index_, int role_) const {
     case Qt::DisplayRole:
       if(parent.isValid()) {
         // it points to an entry
-        return entry(index_)->formattedField(QStringLiteral("title"));
+        return entry(index_)->title();
       }
       // it points to a borrower
       return borrower(index_)->name();
