@@ -54,7 +54,7 @@ void DBCFetcherTest::testTitle() {
   QCOMPARE(results.size(), 1);
 
   Tellico::Data::EntryPtr entry = results.at(0);
-  QCOMPARE(entry->field(QStringLiteral("title")), QStringLiteral("Min kamp. 6"));
+  QCOMPARE(entry->field(QStringLiteral("title")), QStringLiteral("Min kamp. 6. bog"));
   QCOMPARE(entry->field(QStringLiteral("author")), QString::fromUtf8("Karl Ove Knausgård"));
   QCOMPARE(entry->field(QStringLiteral("publisher")), QStringLiteral("Lindhardt og Ringhof"));
   QCOMPARE(entry->field(QStringLiteral("pub_year")), QStringLiteral("2012"));
