@@ -30,10 +30,16 @@
 #include "../collections/bibtexcollection.h"
 #include "../fieldformat.h"
 
+#include <KLocalizedString>
+
 #include <QTest>
 
 QTEST_APPLESS_MAIN( RisTest )
 
+void RisTest::initTestCase() {
+  KLocalizedString::setApplicationDomain("tellico");
+}
+
 void RisTest::testImport() {
   QUrl url = QUrl::fromLocalFile(QFINDTESTDATA("data/test.ris"));
   QList<QUrl> urls;
