@@ -96,13 +96,18 @@ void SRUFetcherTest::testKBTitle() {
   Tellico::Fetch::Fetcher::Ptr fetcher(new Tellico::Fetch::SRUFetcher(this));
   fetcher->readConfig(cg);
 
-  Tellico::Data::EntryList results = DO_FETCH1(fetcher, request, 1);
+  Tellico::Data::EntryList results = DO_FETCH1(fetcher, request, 5);
 
-  QCOMPARE(results.size(), 1);
+  Tellico::Data::EntryPtr entry;
+  foreach(Tellico::Data::EntryPtr testEntry, results) {
+    if(testEntry->field(QStringLiteral("entry-type")) == QStringLiteral("book")) {
+      entry = testEntry;
+      break;
+    }
+  }
+  QVERIFY(entry);
 
-  Tellico::Data::EntryPtr entry = results.at(0);
   QCOMPARE(entry->field(QStringLiteral("title")), QStringLiteral("Godfried Bomans: Erik of het klein insectenboek"));
-//  QCOMPARE(entry->field(QStringLiteral("author")), QStringLiteral("No Author"));
   QCOMPARE(entry->field(QStringLiteral("entry-type")), QStringLiteral("book"));
   QCOMPARE(entry->field(QStringLiteral("publisher")), QStringLiteral("Purmerend : Muusses"));
   QCOMPARE(entry->field(QStringLiteral("isbn")), QStringLiteral("90-231-1704-2"));
@@ -172,13 +177,13 @@ void SRUFetcherTest::testCopacIsbn() {
 void SRUFetcherTest::testHttpFallback() {
   KConfigGroup cg = KSharedConfig::openConfig(QString(), KConfig::SimpleConfig)->group(QStringLiteral("DNB"));
   cg.writeEntry("Format", QStringLiteral("MARC21-xml"));
+  cg.writeEntry("Scheme", QStringLiteral("https"));
   cg.writeEntry("Host", QStringLiteral("services.dnb.de"));
   cg.writeEntry("Path", QStringLiteral("/sru/dnb"));
   cg.writeEntry("Port", 443); // port 443 forces https for this test. Port 80 seems to fallback on the server side
   cg.writeEntry("QueryFields", QStringLiteral("maximumRecords"));
   cg.writeEntry("QueryValues", QStringLiteral("1"));
 
-
   Tellico::Fetch::FetchRequest request(Tellico::Data::Collection::Bibtex, Tellico::Fetch::Title,
                                        QStringLiteral("Goethe"));
   Tellico::Fetch::Fetcher::Ptr fetcher(new Tellico::Fetch::SRUFetcher(this));
@@ -189,5 +194,5 @@ void SRUFetcherTest::testHttpFallback() {
   QCOMPARE(results.size(), 1);
 
   Tellico::Data::EntryPtr entry = results.at(0);
-  QCOMPARE(entry->field(QStringLiteral("title")), QStringLiteral("Briefe an Goethe"));
+  QVERIFY(!entry->field(QStringLiteral("title")).isEmpty());
 }
