@@ -77,7 +77,7 @@ Tellico::Data::CollPtr AMCImporter::collection() {
   QVector<char> buffer(l+1);
   m_ds.readRawData(buffer.data(), l);
   QString version = QString::fromLocal8Bit(buffer.data(), l);
-  QRegularExpression versionRx(QLatin1String(".+AMC_(\\d+)\\.(\\d+).+"));
+  static const QRegularExpression versionRx(QLatin1String(".+AMC_(\\d+)\\.(\\d+).+"));
   QRegularExpressionMatch versionMatch = versionRx.match(version);
   if(!versionMatch.hasMatch()) {
     myDebug() << "no file id match";
@@ -230,7 +230,7 @@ void AMCImporter::readEntry() {
 
   e->setField(QStringLiteral("director"), readString());
   s = readString();
-  QRegularExpression roleRx(QLatin1String("(.+?) \\(([^(]+)\\)"));
+  static const QRegularExpression roleRx(QLatin1String("(.+?) \\(([^(]+)\\)"));
   QRegularExpressionMatch roleMatch = roleRx.match(s);
   if(roleMatch.hasMatch()) {
     QString role = roleMatch.captured(2).toLower();
@@ -251,7 +251,7 @@ void AMCImporter::readEntry() {
   e->setField(QStringLiteral("plot"), readString());
   e->setField(QStringLiteral("comments"), readString());
   s = readString(); // video format
-  QRegularExpression regionRx(QLatin1String("Region \\d"));
+  static const QRegularExpression regionRx(QLatin1String("Region \\d"));
   QRegularExpressionMatch regionMatch = regionRx.match(s);
   if(regionMatch.hasMatch()) {
     e->setField(QStringLiteral("region"), regionMatch.captured());
@@ -274,7 +274,7 @@ void AMCImporter::readEntry() {
 QStringList AMCImporter::parseCast(const QString& text_) {
   QStringList cast;
   int nPar = 0;
-  QRegularExpression castRx(QLatin1String("[,()]"));
+  static const QRegularExpression castRx(QLatin1String("[,()]"));
   QRegularExpressionMatch castMatch = castRx.match(text_);
   QString person, role;
   int oldPos = 0;
