@@ -38,6 +38,7 @@ class QPushButton;
 class QCheckBox;
 class QRadioButton;
 class QTableWidget;
+class CsvTest;
 
 namespace Tellico {
   namespace GUI {
@@ -52,6 +53,8 @@ namespace Tellico {
 class CSVImporter : public TextImporter {
 Q_OBJECT
 
+friend class ::CsvTest;
+
 public:
   /**
    */
@@ -72,6 +75,12 @@ public:
 
   virtual bool validImport() const Q_DECL_OVERRIDE;
 
+  void setCollectionType(int collType);
+  void setImportColumns(const QList<int>& columns, const QStringList& fieldNames);
+  void setDelimiter(const QString& delimeter);
+  void setColumnDelimiter(const QString& delimeter);
+  void setRowDelimiter(const QString& delimeter);
+
 public Q_SLOTS:
   void slotActionChanged(int action) Q_DECL_OVERRIDE;
   void slotCancel() Q_DECL_OVERRIDE;
@@ -92,8 +101,11 @@ private:
   void createCollection();
   void updateFieldCombo();
 
+  int m_collType;
   Data::CollPtr m_coll;
   Data::CollPtr m_existingCollection; // used to grab fields from current collection in window
+  QList<int> m_columnsToImport;
+  QStringList m_fieldsToImport;
   bool m_firstRowHeader;
   QString m_delimiter;
   QString m_colDelimiter;
