@@ -27,39 +27,45 @@
 #include <QTextStream>
 #include <QStringList>
 
+#include <config.h>
+
 extern "C" {
+#ifdef HAVE_LIBCSV
+#include <csv.h>
+#else
 #include "libcsv/libcsv.h"
+#endif
 }
 
 typedef int(*SpaceFunc)(char);
 
-static void writeToken(char* buffer, size_t len, void* data);
-static void writeRow(char buffer, void* data);
-static int isSpace(char c);
-static int isSpaceOrTab(char c);
-static int isTab(char c);
+static void writeToken(void* buffer, size_t len, void* data);
+static void writeRow(int buffer, void* data);
+static int isSpace(unsigned char c);
+static int isSpaceOrTab(unsigned char c);
+static int isTab(unsigned char c);
 
 using Tellico::CSVParser;
 
 class CSVParser::Private {
 public:
-  Private(QString str) {
-    stream = new QTextStream(&str);
+  Private() : stream(nullptr), done(false) {
     csv_init(&parser, 0);
   }
   ~Private() {
-    csv_free(parser);
+    csv_free(&parser);
     delete stream;
   }
 
-  struct csv_parser* parser;
+  struct csv_parser parser;
   QString str;
   QTextStream* stream;
   QStringList tokens;
   bool done;
 };
 
-CSVParser::CSVParser(QString str) : d(new Private(str)) {
+CSVParser::CSVParser(QString str) : d(new Private()) {
+  reset(str);
 }
 
 CSVParser::~CSVParser() {
@@ -68,10 +74,10 @@ CSVParser::~CSVParser() {
 
 void CSVParser::setDelimiter(const QString& s) {
   Q_ASSERT(s.length() == 1);
-  csv_set_delim(d->parser, s[0].toLatin1());
-  if(s[0] == QLatin1Char('\t'))     csv_set_space_func(d->parser, isSpace);
-  else if(s[0] == QLatin1Char(' ')) csv_set_space_func(d->parser, isTab);
-  else                              csv_set_space_func(d->parser, isSpaceOrTab);
+  csv_set_delim(&d->parser, s[0].toLatin1());
+  if(s[0] == QLatin1Char('\t'))     csv_set_space_func(&d->parser, isSpace);
+  else if(s[0] == QLatin1Char(' ')) csv_set_space_func(&d->parser, isTab);
+  else                              csv_set_space_func(&d->parser, isSpaceOrTab);
 }
 
 void CSVParser::reset(QString str) {
@@ -101,34 +107,34 @@ QStringList CSVParser::nextTokens() {
   d->done = false;
   while(hasNext() && !d->done) {
     QByteArray line = d->stream->readLine().toUtf8() + '\n'; // need the eol char
-    csv_parse(d->parser, line, line.length(), &writeToken, &writeRow, this);
+    csv_parse(&d->parser, line.constData(), line.length(), &writeToken, &writeRow, this);
   }
-  csv_fini(d->parser, &writeToken, &writeRow, this);
+  csv_fini(&d->parser, &writeToken, &writeRow, this);
   return d->tokens;
 }
 
-static void writeToken(char* buffer, size_t len, void* data) {
+static void writeToken(void* buffer, size_t len, void* data) {
   CSVParser* p = static_cast<CSVParser*>(data);
-  p->addToken(QString::fromUtf8(buffer, len));
+  p->addToken(QString::fromUtf8((char *)buffer, len));
 }
 
-static void writeRow(char c, void* data) {
+static void writeRow(int c, void* data) {
   Q_UNUSED(c);
   CSVParser* p = static_cast<CSVParser*>(data);
   p->setRowDone(true);
 }
 
-static int isSpace(char c) {
+static int isSpace(unsigned char c) {
   if (c == CSV_SPACE) return 1;
   return 0;
 }
 
-static int isSpaceOrTab(char c) {
+static int isSpaceOrTab(unsigned char c) {
   if (c == CSV_SPACE || c == CSV_TAB) return 1;
   return 0;
 }
 
-static int isTab(char c) {
+static int isTab(unsigned char c) {
   if (c == CSV_TAB) return 1;
   return 0;
 }
