@@ -42,16 +42,13 @@ public:
    */
   VinoXMLImporter(const QUrl& url);
 
-  /**
-   */
-  virtual Data::CollPtr collection() Q_DECL_OVERRIDE;
   /**
    */
   virtual QWidget* widget(QWidget*) Q_DECL_OVERRIDE { return nullptr; }
   virtual bool canImport(int type) const Q_DECL_OVERRIDE;
 
 private:
-  // private so it can't be changed accidently
+  // private so it can't be changed accidentally
   void setXSLTURL(const QUrl& url);
 };
 
