@@ -44,21 +44,21 @@ QString Iso6937Converter::toUtf8(const QByteArray& text_) {
   const uint len = text_.length();
   QString result;
   result.reserve(len);
-  uint pos = 0;
   for(uint i = 0; i < len; ++i) {
-    uchar c = text_[i];
+    uchar c = uchar(text_.at(i));
     if(isAscii(c)) {
-      result[pos++] = c;
+      result.append(QLatin1Char(c));
     } else if(isCombining(c) && hasNext(i, len)) {
-      QChar d = getCombiningChar(c * 256 + text_[i + 1]);
+      const uchar next = uchar(text_.at(i+1));
+      QChar d = getCombiningChar((c << 8) + next);
       if(!d.isNull()) {
-        result[pos++] = d;
+        result.append(d);
         ++i;
       } else {
-        result[pos++] = getChar(c);
+        result.append(getChar(c));
       }
     } else {
-      result[pos++] = getChar(c);
+      result.append(getChar(c));
     }
   }
   result.squeeze();
